#
# spec file for package python-phonenumbers
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-phonenumbers
Version:        8.13.52
Release:        1.2
Summary:        Python version of Google's common library for international phone numbers
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/daviddrysdale/python-phonenumbers
Source:         https://files.pythonhosted.org/packages/source/p/phonenumbers/phonenumbers-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-phonenumberslite = %{version}
BuildArch:      noarch
%python_subpackages

%description
Python version of Google's common library for parsing, formatting, storing
and validating international phone numbers.

%prep
%setup -q -n phonenumbers-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/*test.py

%files %{python_files}
%doc README.md HISTORY.md
%license LICENSE
%{python_sitelib}/phonenumbers
%{python_sitelib}/phonenumbers-%{version}.dist-info

%changelog
* Fri Jan  3 2025 Yunus Acar <yunus.acar@suse.com>
- Update to 8.13.52
  * Merge upstream 8.13.52 phonenumber updates
* Fri Nov 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 8.13.49
  * Merge upstream 8.13.49 phonenumber updates
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.48:
  * merge upstream 8.13.48 phonenumber updates
* Fri Oct 18 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.47:
  * merge upstream 8.13.47 phonenumber updates
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.44:
  * merge upstream 8.13.44 phonenumber updates
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.39:
  * merge upstream 8.13.39 phonenumber updates
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.38:
  * merge upstream 8.13.38 phonenumber updates
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.36:
  * merge upstream 8.13.36 phonenumber updates
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.35:
  * merge upstream 8.13.35 phonenumber updates
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.34:
  * merge upstream 8.13.34 phonenumber updates
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.33:
  * merge upstream 8.13.33 phonenumber updates
* Fri Feb  9 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.30:
  * merge upstream 8.13.30 phonenumber updates
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.29:
  * merge upstream 8.13.29 phonenumber fixes
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 8.13.27:
  * Use re.fullmatch when available
  * merge upstream 8.13.27 phonenumber fixes
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 8.13.26:
  Updated phone metadata for region code(s): EH, HK, HR, MA, MK,
    PK, RO, TJ
  - Updated geocoding data for country calling code(s): 212 (en, fr)
  - Updated carrier data for country calling code(s):
    40 (en), 45 (en), 86 (en, zh), 92 (en), 228 (en), 385 (en),
    852 (en, zh), 992 (en)
- use packaged LICENSE
* Wed Aug  9 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 8.13.18
  - Merge to https://github.com/google/libphonenumber/commit/07cd7bbb8a2f
    relevant code changes:
  - Added a check to phonenumberutil.py that the value of the
    `phone-context` parameter of the tel URI follows the correct
    syntax as defined in
    [RFC3966](https://www.rfc-editor.org/rfc/rfc3966#section-3).
  - Metadata changes
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Jan 30 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 8.13.5
  * Metadata changes
* Thu Dec 29 2022 Michael Ströder <michael@stroeder.com>
- Update to version 8.13.3
  * Metadata changes
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 8.13.2
  * Prep for 8.13.2 release
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 8.13.1
  * Prep for 8.13.1 release
- Update to version 8.13.0
  * tools: don't use clean target in metaclean
    The clean target relies on the coverage tool being installed.
* Sat Oct 15 2022 Michael Ströder <michael@stroeder.com>
- Update to version 8.12.57 with metadata changes
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 8.12.56
  * Metadata changes:
  - Updated phone metadata for region code(s): HR, MK, PT, SG, TT
  - Updated short number metadata for region code(s): BZ
  - Updated carrier data for country calling code(s):
    31 (en), 65 (en), 385 (en), 389 (en)
* Mon Sep 19 2022 Michael Ströder <michael@stroeder.com>
- update to 8.12.55:
  * Many updates to phone metadata
  * Improved tests
  * docs: Fix a few typos
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 8.12.45:
  - Updated phone metadata for region code(s): BF, EE, JM, RE, SE, US
  - New geocoding data for country calling code(s): 1464 (en)
  - Updated carrier data for country calling code(s):
  46 (en), 55 (en), 226 (en), 262 (en), 353 (en), 372 (en), 373 (en),
  1345 (en)
  - Updated / refreshed time zone meta data.
  - Updated phone metadata for region code(s):
  AG, AI, AS, BB, BM, BS, CA, CV, DM, DO, GD, GU, JM, KN, KY, LC, MP, MS, PR,
  SC, SX, TC, TT, US, VC, VG, VI
  - Updated short number metadata for region code(s): BE, PT, SC, SE, US
  - Updated geocoding data for country calling code(s):
  61 (en), 238 (en), 1345 (en)
  - Updated carrier data for country calling code(s): 238 (en), 248 (en)
  - Updated phone metadata for region code(s):
  BJ, CL, GA, IS, KR, KW, LI, PA, SG, SL
  - Updated short number metadata for region code(s): MS
  - Updated geocoding data for country calling code(s): 56 (en, es)
  - Updated carrier data for country calling code(s):
  32 (en), 229 (en), 354 (en), 502 (en), 507 (en)
  - Updated phone metadata for region code(s):
  BG, BI, CF, DZ, GF, GP, HK, IR, MA, MQ, MW, PK, PL, PM, QA, TJ
  - Updated short number metadata for region code(s):
  AG, AI, AS, BB, BM, BS, CA, DM, DO, GD, GU, JM, KN, KY, LC, MP, MS, PR, SX,
  TC, TT, US, VC, VG, VI
  - Updated geocoding data for country calling code(s): 61 (en), 213 (en)
  - Updated carrier data for country calling code(s):
  45 (en), 48 (en), 57 (en), 98 (en, fa), 236 (en), 243 (en), 257 (en),
  420 (en), 421 (en), 508 (en), 675 (en), 852 (en, zh), 974 (en), 992 (en)
  - Updated phone metadata for region code(s): EH, IL, KE, LA, MA, OM, SG
  - Updated short number metadata for region code(s): PY
  - Updated carrier data for country calling code(s):
  33 (en), 65 (en), 358 (en), 383 (en), 420 (en), 502 (en), 856 (en), 966 (en),
  968 (en), 974 (en)
* Thu Jan  6 2022 Michael Ströder <michael@stroeder.com>
- version update to 8.12.40:
  New to_string() methods have been added for enum-like classes,
  emitting strings that describe integer values known to be enum values.
* Mon Dec 13 2021 Michael Ströder <michael@stroeder.com>
- version update to 8.12.39
  - New to_string() methods have been added for enum-like
    classes, emitting strings that describe integer values known
    to be enum values.
  - The library now includes .pyi stub files providing typing
    information about the API, thanks to Adam Turner.
  - Updated As-You-Type-Formatter to exclude patterns where some
    digits would be dropped in the output. This also fixes the
    bug where an extra country code is added in some cases to the
    user's output. b/183053929
  - Changes format_out_of_country_calling_number to always use
    preferred intl prefix if present, not just for numbers with
    a non-unique IDD. This means we will output "8~10" as the
    prefix if calling formatOutOfCountryCallingNumber instead of
    "810" for some regions that have this tilde in their prefix
    [designates that the user should wait before continuing to
    dial].
* Sat Sep 19 2020 John Vandenberg <jayvdb@gmail.com>
- Add %%doc for readme and history files
- Add Provides python-phonenumberslite
- Expand testing from only phonenumbertest.py to all test modules
- Update to v8.12.9
  * see https://github.com/google/libphonenumber/blob/master/release_notes.txt
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 8.12.0
  * metadata updates
  * see https://github.com/google/libphonenumber/blob/master/release_notes.txt
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 8.11.5
  * metadata updates
  * see https://github.com/google/libphonenumber/blob/master/release_notes.txt
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.10.18:
  * metadata updates
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.10.15:
  * updates to metadata informations
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.10.13:
  * Updates from upstream project metadata
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 8.10.8
  * Merge metadata changes from upstream
  * Only compare national number patterns
  * Use class name for repr() instead of hard-coded string
- deleted sources
  - LICENSE (already provided upstream)
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
- Install license file
- Update to 8.10.2:
  * no upstream changelog available
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jan 11 2018 parlt@suse.com
- update to 8.8.9
- no upstream changelog available
* Mon Oct  2 2017 ecsos@opensuse.org
- update to 8.8.2
- convert to  singelspec
* Mon May  1 2017 mrueckert@suse.de
- initial package
